@@ -87,15 +87,16 @@ def encrypt(*args, config: Config, dry_run: bool,
     if verify_dtr is None:
         verify_dtr = not offline and dtr_id is not None
     if offline and verify_dtr:
-        raise UserError(
-            "--verify_dtr is not possible when offline is enabled in the config")
+        raise UserError("--verify_dtr is not possible when offline is "
+                        "enabled in the config")
     if config.sign_encrypted_data and not dry_run:
         kwargs["passphrase"] = get_passphrase_from_cmd_or_prompt(
             passphrase_cmd)
     else:
         kwargs["passphrase"] = None
-    return workflows_encrypt(*args, dtr_id=dtr_id, offline=offline, verify_dtr=verify_dtr,
-                             config=config, dry_run=dry_run, **kwargs)
+    return workflows_encrypt(*args, dtr_id=dtr_id, offline=offline,
+                             verify_dtr=verify_dtr, config=config,
+                             dry_run=dry_run, **kwargs)
 
 
 @wraps(workflows_decrypt)
@@ -155,9 +156,13 @@ class Cli(Subcommands):
     passphrase_override = dict(help="Instead of asking for passphrase, "
                                     "get it from an external command "
                                     "(passphrase must be returned to the "
-                                    "standard output)",
+                                    "standard output).",
                                name="passphrase-cmd",
                                dest="passphrase_cmd")
+    dry_run_override = dict(help="Perform checks on the input data, whithout "
+                        "running the actual command.")
+    verify_dtr_override = dict(help="Verify DTR ID against online database.",
+                      default=None)
     logger = logging.getLogger()
     add_rotating_file_handler_to_logger(logger,
                                         log_dir=config.log_dir,
@@ -171,18 +176,21 @@ class Cli(Subcommands):
                      lazy_partial(progress=CliProgress)
                      ),
             overrides={
-                "files": dict(help="Input file(s) or directories"),
+                "files": dict(help="Input file(s) or directories."),
                 "sender": dict(help="fingerprint, key ID or email associated "
                                     "with GPG key of data sender.",
                                alias='-s'),
-                "recipient": dict(help="fingerprint, key ID or email associated "
-                                  "with GPG key of data recipient(s).",
-                                  alias='-r'),
-                "dtr_id": dict(help="Data Transfer Request (DTR) ID (optional)", alias='-t'),
-                "verify_dtr": dict(help="Verify DTR ID", default=None),
+                "recipient": dict(
+                    help="fingerprint, key ID or email associated with "
+                         "GPG key of data recipient(s).",
+                    alias='-r'),
+                "dtr_id": dict(
+                    help="Data Transfer Request (DTR) ID (optional).",
+                    alias='-t'),
+                "verify_dtr": verify_dtr_override,
                 "purpose": dict(
                     help="Purpose of the DTR (PRODUCTION, TEST)."
-                         "Mandatory only if `transfer_id` is specified"),
+                         "Mandatory only if `transfer_id` is specified."),
                 "output_name": dict(
                     help="output encrypted file name. If no path is specified, "
                          "the output tarball is saved in the current working "
@@ -191,10 +199,12 @@ class Cli(Subcommands):
                          "the current date and time the function.",
                     default=None,
                     alias='-o'),
-                "dry_run": dict(
-                    help="Use this flag to perform checks on the data only."),
-                "compress": dict(
-                    help="Compress the inner tarball"),
+                "dry_run": dry_run_override,
+                "compression_level": dict(
+                    help="compression level for inner tarball in the range "
+                         "0 (no compression) to 9 (highest compression). "
+                         "Higher compression levels require more computing "
+                         "time."),
                 "passphrase": passphrase_override
             }),
         Subcommand(
@@ -213,13 +223,14 @@ class Cli(Subcommands):
                 "protocol_args": dict(help="Protocol specific arguments. "
                                       "Must be passed as a json string",
                                       type=parse_protocol_args),
-                "connection": dict(help="Instead of the option 'protocol', load a "
-                                   "connection named by the argument of this option "
-                                   "to use the protocol and protocol args from the "
-                                   "config. The protocol args can be overwritten by "
-                                   "the protocol_args option"),
-                "dry_run": dict(help="Use this flag to perform checks on the data only"),
-                "verify_dtr": dict(help="Verify DTR ID")
+                "connection": dict(
+                    help="Instead of the option 'protocol', load a connection "
+                         "named by the argument of this option to use the "
+                         "protocol and protocol args from the config. The "
+                         "protocol args can be overwritten by the "
+                         "protocol_args option"),
+                "dry_run": dry_run_override,
+                "verify_dtr": verify_dtr_override
             }),
         Subcommand(
             decorate(
@@ -228,9 +239,10 @@ class Cli(Subcommands):
                 lazy_partial(progress=CliProgress)
             ),
             overrides={
-                "output_dir": dict(help="Output directory", default=os.getcwd(), alias="-o"),
-                "decrypt_only": dict(help="Skip extraction"),
-                "dry_run": dict(help="Use this flag to perform checks on the data only"),
+                "output_dir": dict(help="Output directory.",
+                                   default=os.getcwd(), alias="-o"),
+                "decrypt_only": dict(help="Skip extraction."),
+                "dry_run": dry_run_override,
                 "passphrase": passphrase_override
             }
         ),
