@@ -3,13 +3,19 @@ import io
 import tarfile
 import time
 from abc import ABC, abstractmethod
-from typing import List, Iterable, IO, Sequence, Union
 from pathlib import Path
 from contextlib import contextmanager
 from itertools import filterfalse
+from typing import List, Iterable, IO, Sequence, Union
+try:
+    from typing import TypedDict
+except ImportError:
+    from typing_extensions import TypedDict
 
 from .error import UserError
 from .filesystem import delete_files
+from ..utils.progress import ProgressInterface, with_progress, progress_iter
+
 
 tarfile.DEFAULT_FORMAT = tarfile.PAX_FORMAT
 
@@ -22,16 +28,26 @@ PACKAGE_CONTENT = {METADATA_FILE, METADATA_FILE_SIG, DATA_FILE_ENCRYPTED}
 CONTENT_FOLDER = "content"
 
 
-def check_tar(tar: str):
+def check_tar(tar: str) -> None:
+    """Checks that a tar file has the correct content structure and correct
+    file name extension.
+
+    :param tar: path to the tarfile
+    :raises UserError:
+    """
     if not tar.endswith(".tar"):
-        raise UserError(
-            "Input file '{}' does not have .tar extension.\n"
-            "Only .tar files can be used as input of the data decryption command.".format(tar))
+        raise UserError(f"Input file '{tar}' does not have .tar extension.\n"
+                        "Only .tar files can be used as input of the data "
+                        "decryption command.")
     check_tar_contents(os.path.realpath(tar))
 
 
-def check_tar_contents(path: str):
-    """Checks for exactly one .json file and exactly one .tar.gz.gpg"""
+def check_tar_contents(path: str) -> None:
+    """Checks for exactly one .json file and exactly one .tar.gz.gpg
+
+    :param path: path to the tarfile
+    :raises UserError:
+    """
     with tarfile.open(path, format=tarfile.PAX_FORMAT) as tar:
         content = set(tar.getnames())
         content.add(METADATA_FILE_SIG)  # NOTE: Backward compatibility to v0.9
@@ -39,7 +55,8 @@ def check_tar_contents(path: str):
             raise UserError(
                 f"Input file '{path}' has non-compliant content:\n" +
                 "\n".join(content) + "\n\n"
-                "BiomedIT input tar files must contain exactly the following files:\n"
+                "BioMedIT input tar files must contain exactly the following "
+                "files:\n"
                 f"\t- {METADATA_FILE} file with metadata\n"
                 f"\t- {DATA_FILE_ENCRYPTED} file with the encrypted data"
             )
@@ -56,8 +73,7 @@ class ArchiveFileBase(ABC):
 
 
 class ArchiveInMemoryFile(ArchiveFileBase):
-    """An ArchiveFileBase whose content_container is a bytes instance"""
-
+    """An ArchiveFileBase whose content_container is a bytes instance."""
     def add_to_tar(self, tar: tarfile.TarFile):
         t = tarfile.TarInfo(self.archive_path)
         t.size = len(self.content_container)
@@ -66,8 +82,7 @@ class ArchiveInMemoryFile(ArchiveFileBase):
 
 
 class ArchiveFile(ArchiveFileBase):
-    """An ArchiveFileBase whose content_container is a file like object"""
-
+    """An ArchiveFileBase whose content_container is a file like object."""
     def add_to_tar(self, tar: tarfile.TarFile):
         t = tar.gettarinfo(name=self.content_container.name,
                            arcname=self.archive_path,
@@ -78,35 +93,58 @@ class ArchiveFile(ArchiveFileBase):
 
 def write_tar(content: Sequence[ArchiveFileBase],
               output: Union[str, IO[bytes]],
-              mode="w:gz") -> None:
-    """Create a tar.gz archive with files of input file_list.
+              compress_level: int = 6,
+              compress_algo: str = 'gz') -> None:
+    """Create a ".tar" or ".tar.gz" archive from files on disk or from a
+    data stream, i.e. in-memory files.
 
-    :param content: Files / In-memory-files that will be added to the tar archive.
+    :param content: (in-memory) files to be added to the tar archive.
     :param output: path (or file object) or stream for the output tarball.
-    :param mode: Mode to be passed to tarfile, i.e. `'w:gz'`
+    :param compress_algo: compression algorithm to use when compressing
+        the tar file (if compress_level > 0). Possible choices are
+        'gz' (for gzip compression) and 'bz2' (for bzip2 compression).
+    :param compress_level: gzip/bzip2 compression level in the range 0 (no
+        compression) to 9 (highest compression).
     :raises UserError:
     """
+    # Create a TypedDict class so that the mypy linter does not complain
+    # aboute "Incompatible types in assignment".
+    class TarfileArguments(TypedDict, total=False):
+        name: str
+        fileobj: IO[bytes]
+        mode: str
+        compresslevel: int
 
-    arch_names = set(f.archive_path for f in content)
-    assert_relative(arch_names)
+    archive_file_names = set(f.archive_path for f in content)
+    assert_relative(archive_file_names)
 
+    # Set correct mode depending on compression level and type of output,
+    # i.e. file vs fileobject.
+    # Note that currently the "w|gz" mode do not support the "compresslevel"
+    # argument, so we use "w:gz" instead.
+    tarfile_arguments: TarfileArguments = {'mode': f'w:{compress_algo}' if
+        compress_level > 0 else 'w' if isinstance(output, str) else 'w|'}
     if isinstance(output, str):
-        open_tar = tarfile.open(name=output, mode=mode)
+        tarfile_arguments['name'] = output
     else:
-        open_tar = tarfile.open(fileobj=output, mode=mode)
+        tarfile_arguments['fileobj'] = output
+    tarfile_arguments['mode'] = f'w:{compress_algo}' if compress_level > 0 \
+        else 'w' if isinstance(output, str) else 'w|'
+    if compress_level > 0:
+        tarfile_arguments['compresslevel'] = compress_level
+
     # Compress input files into tarball.
-    with open_tar as tar:
+    with tarfile.open(**tarfile_arguments) as tar:
         for archive_file in content:
             archive_file.add_to_tar(tar)
 
     if isinstance(output, str):
-        # Verify the tarball file was created correctly. If it's not the case,
-        # delete it.
+        # Verify the tarball file was created correctly. If not, delete it.
         if not Path(output).is_file():
             raise UserError(f'compression failed for [{output}]: '
                             f'tarball not created.')
         with tarfile.open(output, 'r') as tar:
-            missing_files = {Path(p) for p in arch_names} - \
+            missing_files = {Path(p) for p in archive_file_names} - \
                             {Path(p) for p in tar.getnames()}
         if missing_files:
             delete_files(output)
@@ -139,6 +177,34 @@ def check_extracted(paths: Iterable[str]):
                         "\n".join(failed))
 
 
+@contextmanager
+def extract_with_progress(archive: IO[bytes], progress: ProgressInterface, *files):
+    """Extracts given files from given archive.
+
+    If only one file is specified, then progression scales with untaring of
+    this specific file. Otherwise, each file takes an equal part (independent
+    of its size) to progression.
+
+    :param archive: the archive file.
+    :param progress: the ProgressInterface. Must be specified.
+    :param files: the list of tar members we want to untar.
+    :raises UserError: if a 'KeyError' is thrown
+    :returns: yields an io.BufferedReader or a casted 'FileObjectProgress'
+    """
+    with archive as a, tarfile.open(fileobj=a) as tar:
+        try:
+            if len(files) == 1:
+                member = tar.extractfile(files[0])
+                yield with_progress(member, progress) if member else None
+            else:
+                yield (tar.extractfile(file_name) for
+                       file_name in progress_iter(files, progress))
+        # 'tarfile.getmember' ('extractfile' invokes it): If 'file_name' can
+        # not be found in the archive, 'KeyError' is raised.
+        except KeyError as e:
+            raise UserError(f"In archive {archive.name}: {e}") from e
+
+
 @contextmanager
 def extract(archive: IO[bytes], *files):
     with archive as a:
@@ -156,14 +222,14 @@ def extract(archive: IO[bytes], *files):
 def unpack_from_stream(archive: IO[bytes], dest: str, content: List[str],
                        mode: str = 'r|*'):
     """Extract all files in the tarball from a stream.
-
     After unpacking the function checks that all files have been properly
     extracted by comparing the new files on disk to the list of files present
     in the tarball.
 
     :param archive: tarball stream
     :param dest: destination directory for the unpacked data
-    :param content: a list container to store the file names compressed in the tarball
+    :param content: a list container to store the file names compressed in
+        the tarball
     :param mode: Mode to be passed to tarfile, i.e. `'r|*'`
     """
     if not os.path.isdir(dest):
