@@ -27,10 +27,11 @@ def compute_checksum_sha256(file_object: IO[bytes],
 def compute_checksum_on_write(stream: IO[bytes],
                               fout: io.FileIO,
                               checksum_buffer: io.StringIO,
-                              block_size: int = 65536):
-    """Compute a sha256 checksum on stream while saving to a file.
+                              block_size: int = 65536) -> None:
+    """Compute a sha256 checksum on stream while writing it to a file at the
+    same time.
 
-    :param stream: a stream of bytes to checksum and save.
+    :param stream: a stream of bytes to checksum and write to disk.
     :param fout: output file object.
     :param checksum_buffer: a buffer to store the checksum.
     :param block_size: size of blocks (in bytes) to be returned by the
