@@ -146,7 +146,6 @@ def open_gpg_dir(gpg_dir: str) -> GPGStore:
     :return: a gnupg GPGStore
     :raises UserError:
     """
-
     if not Path(gpg_dir).is_dir():
         os.makedirs(gpg_dir, mode=0o700)
 
@@ -279,9 +278,12 @@ def encrypt_and_sign(source: Callable,
     """Encrypt input data with a GnuPG public key and sign it with a GnuPG
     private key.
 
-    Note: in this function we do not check the validity of the sender and
-    recipient keys, because it is assumed that this is already done earlier
-    in the workflow.
+    In this function, the compression level of the "encrypt()" method is set
+    to 0 as we are only encrypting data that has already been compressed, or
+    has explicitely been requeseted by the user not to be compressed.
+
+    There is no check of the validity of the sender and recipient keys, as it
+    is assumed that this is already done earlier.
 
     :param source: callable writing data to encrypt.
     :param output: callable reading encrypted data.
@@ -299,14 +301,17 @@ def encrypt_and_sign(source: Callable,
     :raises UserError:
     """
     try:
+        # Note: gpg.CompressAlgo.NONE evaluates to "uncompressed", which
+        # tells GnuPG to not compress the input data.
         gpg_store.encrypt(
             source=source,
             recipients=recipients_fingerprint,
-            sign=signature_fingerprint,
             output=output,
             passphrase=passphrase,
             trust_model=gpg.TrustModel.always if always_trust
-            else gpg.TrustModel.pgp)
+                        else gpg.TrustModel.pgp,
+            sign=signature_fingerprint,
+            compress_algo=gpg.CompressAlgo.NONE)
     except gpg.cmd.GPGError:
         raise UserError("Encryption failed. "
                         "Maybe you entered a wrong passphrase.") from None
@@ -316,8 +321,11 @@ def get_recipient_email(key: gpg.Key) -> str:
     try:
         email = key.uids[0].email
     except (IndexError, UnpackError):
-        raise UserError(
-            f"Could not determine email address for gpg key {key.key_id}.") from None
+        raise UserError(f"Could not determine email address "
+                        f"for GPG key {key.key_id}.") from None
+    if not email:
+        raise UserError(f"GPG key [{key.key_id}] does not contain a valid "
+                        f"email address.")
     return email
 
 
