@@ -1,9 +1,14 @@
 import os
-from typing import List, Iterator
-from pathlib import Path
+import shutil
 import warnings
-from .error import UserError
+from itertools import count
+from pathlib import Path
+from typing import List, Iterator, Union
 
+from .error import UserError
+from ..utils.log import create_logger
+
+logger = create_logger(__name__)
 
 def search_files_recursively(input_list: List[str]) -> Iterator[str]:
     """Recursively search for files and/or verify that files part of
@@ -84,3 +89,31 @@ def form_output_tar_name(output_name: str) -> str:
         raise UserError(f"no write permission on directory: {output_dir}")
 
     return output_dir.joinpath(basename).as_posix()
+
+
+def unique_filename(filename: str, extension: str = '', separator: str = '_',
+                    first_number: int = 1):
+    def filename_canditates():
+        yield f'{filename}{extension}'
+        yield from (f'{filename}{separator}{i}{extension}' for i in count(start=first_number))
+    return next(candidate for candidate in filename_canditates() if not os.path.exists(candidate))
+
+
+class DeleteDirOnError:
+    '''Context Manager to delete the specified directory including all of its files
+     in case of an exception.
+    '''
+    def __init__(self, directory: Union[str, Path]):
+        self.directory = directory
+
+    def __enter__(self):
+        return self.directory
+
+    def __exit__(self, exception_type, value, traceback):
+        if traceback is not None:
+            # Exception occurred
+            if os.path.isdir(self.directory):
+                logger.debug("Deleting directory: %s", self.directory)
+                shutil.rmtree(self.directory)
+            else:
+                logger.debug("Directory doesn't exist: %s", self.directory)
