@@ -218,7 +218,7 @@ class EncryptTab(QtWidgets.QWidget, TabMixin):
             output_name=output_path,
             dry_run=dry_run,
             offline=self.app_data.config.offline,
-            compress=self.app_data.encrypt_compress,
+            compression_level=None if self.app_data.encrypt_compress else 0,
             purpose=self.app_data.encrypt_purpose,
             progress=progress,
             on_error=lambda _: None)
