@@ -141,3 +141,6 @@ class AppData:
         self._listeners = defaultdict(list) # pylint: disable=attribute-defined-outside-init
         if self.config.offline:
             self.encrypt_verify_dtr = self.transfer_verify_dtr = False
+        if self.config.output_dir:
+            self.encrypt_output_location = Path(self.config.output_dir)
+            self.decrypt_output_location = Path(self.config.output_dir)
