@@ -3,12 +3,13 @@ import operator
 from pathlib import Path
 
 import time
-
 from PySide2 import QtWidgets, QtCore
 
-from .. import protocols
-from .component import TabMixin, FileSelectionWidget, PathInput, GuiProgress, run_dialog
+from .component import TabMixin, PathInput,\
+    GuiProgress, run_dialog, MandatoryLabel
+from .file_selection_widget import ArchiveOnlyFileSelectionWidget
 from .parallel import Worker
+from .. import protocols
 from ..workflows import transfer
 
 
@@ -24,6 +25,7 @@ class TransferTab(QtWidgets.QWidget, TabMixin):
         options_panel = self.create_options_panel()
         self.create_run_panel("Transfer data", self.transfer,
                               "Transfer selected files")
+        self.app_data.add_listener('transfer_files', self._enable_buttons)
         self.create_console()
         self.create_progress_bar()
 
@@ -35,9 +37,11 @@ class TransferTab(QtWidgets.QWidget, TabMixin):
         layout.addWidget(self.progress_bar, 4, 0, 1, 2)
         self.setLayout(layout)
 
+    def _enable_buttons(self):
+        self.set_buttons_enabled(len(self.app_data.transfer_files) > 0)
+
     def create_files_panel(self):
-        box = FileSelectionWidget("Select encrypted files to transfer",
-                                  self, directory=False, archives_only=True)
+        box = ArchiveOnlyFileSelectionWidget("Encrypted files to transfer", self)
         box.file_list_model.layoutChanged.connect(
             lambda: setattr(self.app_data, "transfer_files", box.get_list()))
         return box
@@ -46,46 +50,55 @@ class TransferTab(QtWidgets.QWidget, TabMixin):
         field_mapping = FieldMapping()
 
         text_username = field_mapping.bind_text("username", QtWidgets.QLineEdit())
+        text_username.setStatusTip("Username on the SFTP server")
         text_destination_dir = field_mapping.bind_text("destination_dir", QtWidgets.QLineEdit())
         text_username.editingFinished.connect(lambda:
             operator.setitem(self.app_data.transfer_protocol_args["sftp"],
                              "username", text_username.text()))
         text_host = field_mapping.bind_text("host", QtWidgets.QLineEdit())
+        text_host.setStatusTip("URL of the SFTP server with an optional port "
+                               "number")
         text_host.editingFinished.connect(lambda:
             operator.setitem(self.app_data.transfer_protocol_args["sftp"],
                             "host", text_host.text()))
         text_jumphost = field_mapping.bind_text("jumphost", QtWidgets.QLineEdit())
+        text_jumphost.setStatusTip("(optional) URL of the jumphost server")
         text_jumphost.editingFinished.connect(lambda:
             operator.setitem(self.app_data.transfer_protocol_args["sftp"],
                              "jumphost", text_jumphost.text() or None))
         text_destination_dir.editingFinished.connect(lambda:
             operator.setitem(self.app_data.transfer_protocol_args["sftp"],
                             "destination_dir", text_destination_dir.text()))
+        text_destination_dir.setStatusTip("Relative or absolute path to the "
+                                          "destination directory on the SFTP "
+                                          "server")
         pkey_location = field_mapping.bind_path("pkey", PathInput(directory=False, path=None))
         pkey_location.btn_label = "Select private key"
+        pkey_location.status_tip = "Path to the private SSH key used for authentication"
         pkey_location.on_path_change(lambda path:
             operator.setitem(self.app_data.transfer_protocol_args["sftp"],
                              "pkey", "" if path is None else str(path)))
         pkey_password = field_mapping.bind_text("pkey_password", QtWidgets.QLineEdit())
+        pkey_password.setStatusTip("Passphrase for the SSH private key")
         pkey_password.setEchoMode(QtWidgets.QLineEdit.Password)
         pkey_password.editingFinished.connect(lambda:
             operator.setitem(self.app_data.transfer_protocol_args["sftp"],
                              "pkey_password", pkey_password.text()))
 
         layout = QtWidgets.QGridLayout()
-        layout.addWidget(QtWidgets.QLabel("User name"), 0, 0)
+        layout.addWidget(MandatoryLabel("User name"), 0, 0)
         layout.addWidget(text_username, 0, 1)
-        layout.addWidget(QtWidgets.QLabel("Host URL"), 1, 0)
+        layout.addWidget(MandatoryLabel("Host URL"), 1, 0)
         layout.addWidget(text_host, 1, 1)
-        layout.addWidget(QtWidgets.QLabel("Jumphost URL (if needed)"), 2, 0)
+        layout.addWidget(QtWidgets.QLabel("Jumphost URL"), 2, 0)
         layout.addWidget(text_jumphost, 2, 1)
-        layout.addWidget(QtWidgets.QLabel("Destination directory"), 3, 0)
+        layout.addWidget(MandatoryLabel("Destination directory"), 3, 0)
         layout.addWidget(text_destination_dir, 3, 1)
-        layout.addWidget(QtWidgets.QLabel("SSH key location (optional)"), 4, 0)
+        layout.addWidget(QtWidgets.QLabel("SSH key location"), 4, 0)
         layout.addWidget(pkey_location.text, 4, 1)
         layout.addWidget(pkey_location.btn, 4, 2)
         layout.addWidget(pkey_location.btn_clear, 4, 3)
-        layout.addWidget(QtWidgets.QLabel("SSH key password (optional)"), 5, 0)
+        layout.addWidget(QtWidgets.QLabel("SSH key password"), 5, 0)
         layout.addWidget(pkey_password, 5, 1)
         box = QtWidgets.QGroupBox("Parameters")
         box.setFlat(True)
@@ -104,9 +117,9 @@ class TransferTab(QtWidgets.QWidget, TabMixin):
             self.app_data.transfer_protocol_args["liquid_files"],
             "api_key", text_api_key.text()))
         layout = QtWidgets.QGridLayout()
-        layout.addWidget(QtWidgets.QLabel("Host URL"), 0, 0)
+        layout.addWidget(MandatoryLabel("Host URL"), 0, 0)
         layout.addWidget(text_host, 0, 1)
-        layout.addWidget(QtWidgets.QLabel("API Key"), 1, 0)
+        layout.addWidget(MandatoryLabel("API Key"), 1, 0)
         layout.addWidget(text_api_key, 1, 1)
         box = QtWidgets.QGroupBox("Parameters")
         box.setFlat(True)
@@ -115,19 +128,28 @@ class TransferTab(QtWidgets.QWidget, TabMixin):
         return box
 
     def create_options_panel(self):
-        box = QtWidgets.QGroupBox("Select data transfer options")
+        box = QtWidgets.QGroupBox("Connection")
 
-        verify = QtWidgets.QCheckBox("Verify DTR ID")
-        verify.setStatusTip("Verify DTR (Data Transfer Request) ID")
-        verify.setChecked(self.app_data.transfer_verify)
-        verify.stateChanged.connect(lambda state:
-            setattr(self.app_data, "transfer_verify",
+        verify_dtr = QtWidgets.QCheckBox("Verify DTR ID")
+        verify_dtr.setStatusTip("Verify DTR (Data Transfer Request) ID")
+        verify_dtr.setChecked(not self.app_data.config.offline and
+                              self.app_data.transfer_verify_dtr)
+        if self.app_data.config.offline:
+            verify_dtr.setEnabled(not self.app_data.config.offline)
+            verify_dtr.setStatusTip("Verifying Transfer Request ID in offline mode is not possible")
+        verify_dtr.stateChanged.connect(lambda state:
+            setattr(self.app_data, "transfer_verify_dtr",
                     state == QtCore.Qt.Checked))
 
         connections_selection = QtWidgets.QComboBox(box)
+        connections_selection.setStatusTip(
+            "Select a predefined connection profile. "
+            "Check documentation for details.")
         connections_selection.addItems(list(self.app_data.config.connections))
 
         protocol_selection = QtWidgets.QComboBox(box)
+        protocol_selection.setStatusTip("Select a protocol for the connection "
+                                        "to the remote server")
         protocol_selection.addItems(["sftp", "liquid_files"])
 
         box_sftp = self.create_sftp_options_panel()
@@ -154,7 +176,7 @@ class TransferTab(QtWidgets.QWidget, TabMixin):
                 box_liquidfiles.setVisible(not box_liquidfiles.isVisible())))
 
         layout = QtWidgets.QVBoxLayout()
-        layout.addWidget(verify)
+        layout.addWidget(verify_dtr)
         layout.addWidget(QtWidgets.QLabel("Predefined connections"))
         layout.addWidget(connections_selection)
         layout.addWidget(QtWidgets.QLabel("Protocol"))
@@ -166,13 +188,6 @@ class TransferTab(QtWidgets.QWidget, TabMixin):
         return box
 
     def transfer(self, dry_run=False):
-        if not self.app_data.transfer_files:
-            msg_warn = QtWidgets.QMessageBox()
-            msg_warn.setWindowTitle("Warning")
-            msg_warn.setText("Select files for transfer.")
-            msg_warn.setIcon(QtWidgets.QMessageBox.Warning)
-            msg_warn.exec_()
-            return
         progress = GuiProgress()
         progress.updated.connect(self.progress_bar.setValue)
 
@@ -213,7 +228,7 @@ class TransferTab(QtWidgets.QWidget, TabMixin):
                 self.app_data.transfer_protocol_name],
             config=self.app_data.config,
             dry_run=dry_run,
-            verify=self.app_data.transfer_verify,
+            verify_dtr=self.app_data.transfer_verify_dtr,
             progress=progress,
             on_error=lambda _: None,
             two_factor_callback=second_factor_callback)
