@@ -58,6 +58,7 @@ class Config:
     ssh_password_encoding: str = "utf_8"
     default_sender: Optional[str] = None
     gui_quit_confirmation: bool = True
+    compression_level: int = 5
 
     def __post_init__(self):
         for url in ('dcc_portal_url', 'repo_url'):
@@ -65,21 +66,21 @@ class Config:
 
     @property
     def dcc_portal_pgpkey_endpoint_url(self) -> str:
-        return self.dcc_portal_url + "/backend/pgpkey-sign-request/"
+        return self.dcc_portal_url + "/backend/pgpkey/sign-request/"
 
     @property
     def dcc_portal_dpkg_endpoint_url(self) -> str:
-        return self.dcc_portal_url + "/backend/data-package/"
+        return self.dcc_portal_url + "/backend/data-package/check/"
 
     @property
     def gpg_store(self):
-        return exception_to_message(UserError, logger)(open_gpg_dir)(self.gpg_config_dir)
+        return exception_to_message(
+            UserError, logger)(open_gpg_dir)(self.gpg_config_dir)
 
 
 @exception_to_message(logger=logger)
 def load_config() -> Config:
     """Loads the config, returning a Config object"""
-
     cfg_dct = sys_config_dict()
     cfg_dct.update(load_config_dict(get_config_file()))
     return deserialize(Config)(cfg_dct)
@@ -87,9 +88,7 @@ def load_config() -> Config:
 
 def create_config() -> str:
     """Creates a new config file in the home directories config folder
-
     :return: The path of the created file"""
-
     config_dir = get_config_dir()
     if not os.path.isdir(config_dir):
         os.makedirs(config_dir)
@@ -134,13 +133,11 @@ def load_config_dict(path: str) -> dict:
 
 def get_config_file() -> str:
     """user platform specific config file"""
-
     return os.path.join(get_config_dir(), CONFIG_FILE_NAME)
 
 
 def get_config_dir() -> str:
     """user platform specific config direcory"""
-
     return os.path.join(
         os.path.expanduser("~"),
         *conf_sub_dir_by_os[platform.system()],
