@@ -248,7 +248,6 @@ class FileObjectProgress:
 
     def __init__(self, f_obj: IO[bytes], progress):
         self._f = f_obj
-        self._update = progress.update
         original_pos = f_obj.tell()
         f_obj.seek(0, io.SEEK_END)
         total_size = f_obj.tell() - original_pos
@@ -329,20 +328,6 @@ class Opener:
         return self._f.__exit__(*args)
 
 
-def progress_file(path: str,
-                  mode: str,
-                  progress: Optional[ProgressInterface]) -> IO[bytes]:
-    """Associate an input file with a progress object.
-
-    :param path: file to which progress should be associated.
-    :param mode: file access mode, e.g. 'rb', 'r'.
-    :param progress: ProgressInterface to which the file is associated.
-    :return: file object with backed-in progress.
-    """
-    return cast(IO[bytes], Opener(
-        path, mode=mode, wrapper=with_progress_decorator(progress)))
-
-
 def progress_file_iter(files: List[str],
                        mode: str,
                        progress: Optional[ProgressInterface]) \
@@ -376,4 +361,5 @@ def progress_file_iter(files: List[str],
 def with_progress_decorator(progress):
     def _wrapper(f):
         return with_progress(f=f, progress=progress)
+
     return _wrapper
