@@ -3,7 +3,7 @@ import json
 import os
 from functools import partial
 from pathlib import Path
-from typing import List, Optional, Callable, Tuple
+from typing import List, Optional, Callable, Tuple, Union
 
 from . import workflow
 from ..utils.config import Config
@@ -18,7 +18,8 @@ from ..core.crypt import retrieve_keys, encrypt_and_sign, \
     detach_sign_file, check_password
 from ..core.checksum import write_checksums, compute_checksum_on_write
 from ..core.error import UserError
-from ..core.metadata import MetaData, alnum_str, Purpose, HexStr1024, HexStr256, verify_transfer
+from ..core.metadata import MetaData, alnum_str, Purpose, HexStr1024, \
+    HexStr256, verify_transfer
 from ..utils.progress import ProgressInterface, subprogress, progress_file_iter
 
 DATE_FMT_FILENAME = "%Y%m%dT%H%M%S"
@@ -52,7 +53,7 @@ def path_str(directory: bool = False, writable: bool = False) -> Callable:
 output_path_str = path_str(directory=True, writable=True)
 
 
-def check_arg_value(arg_value: str,
+def check_arg_value(arg_value: Union[str, int],
                     arg_name: str,
                     arg_type: Callable) -> None:
     """Verify that the value of variable arg_value that is named arg_name is
@@ -65,6 +66,24 @@ def check_arg_value(arg_value: str,
         raise UserError(f"Invalid value for argument '{arg_name}': {e}") from e
 
 
+def check_integer_in_range(min_value: int, max_value: int) -> Callable:
+    """Generate a function that will check that its input value is an integer,
+    and that this integer is in the range [min_value:max_value].
+    """
+    def _integer_in_range(value_to_check: Union[int, str]) -> None:
+        try:
+            value_to_check = int(value_to_check)
+        except ValueError as e:
+            raise ValueError("value must be an integer") from e
+
+        if value_to_check < min_value or value_to_check > max_value:
+            raise ValueError(f"value must be in the range "
+                             f"[{min_value}-{max_value}]")
+    return _integer_in_range
+
+check_compression_level = check_integer_in_range(min_value=0, max_value=9)
+
+
 # pylint: disable=too-many-statements
 @workflow(logger, (UserError, FileNotFoundError, PermissionError))
 def encrypt(files: List[str],
@@ -78,16 +97,22 @@ def encrypt(files: List[str],
             dry_run: bool = False,
             offline: bool = False,
             verify_dtr: bool = True,
-            compress: bool = True,
+            compression_level: Optional[int] = None,
             purpose: Optional[Purpose] = None,
             progress: ProgressInterface = None) -> None:
     """Compress and encrypt files and/or directories.
     """
 
+    # Retrive non-specified, optional argument values from config.
     if sender is None:
         sender = config.default_sender or config.gpg_store.default_key()
         if sender is None:
             raise UserError("Sender not specified with no default sender.")
+    if compression_level is None:
+        compression_level = config.compression_level
+    check_arg_value(arg_value=compression_level,
+                    arg_name="compression level",
+                    arg_type=check_compression_level)
 
     if not files:
         raise UserError("Empty file list")
@@ -177,7 +202,8 @@ def encrypt(files: List[str],
                                        mode='rb',
                                        progress=scaled_progress)))
 
-    with logger.log_task("Compress and encrypt input data [this may take a while]"):
+    with logger.log_task("Compress and encrypt input data "
+                         "[this can take a while]"):
         # Encryption is done with the recipient's public key and the optional
         # signing with the user's (i.e sender) private key. The user's private
         # key passphrase is needed to sign the encrypted file.
@@ -185,7 +211,7 @@ def encrypt(files: List[str],
         encrypted_checksum_buf = io.StringIO()
         with subprogress(progress,
                          step_completion_increase=0.75) as scaled_progress:
-            # Create a tar archive contaiing all input files
+            # Create a tar archive containing all input files
             archive_content: Tuple[ArchiveFileBase, ...] = \
                 ((ArchiveInMemoryFile(CHECKSUM_FILE, checksums),) +
                 tuple(ArchiveFile(a_path, f) for a_path, f in zip(
@@ -197,7 +223,8 @@ def encrypt(files: List[str],
                 encrypt_and_sign(
                     source=partial(write_tar,
                                    archive_content,
-                                   mode="w|gz" if compress else "w|"),
+                                   compress_level=compression_level,
+                                   compress_algo='gz'),
                     output=partial(compute_checksum_on_write,
                                    fout=fout,
                                    checksum_buffer=encrypted_checksum_buf),
@@ -205,9 +232,9 @@ def encrypt(files: List[str],
                     recipients_fingerprint=[key.fingerprint
                                             for key in recipients_pub_key],
                     signature_fingerprint=sender_pub_key.fingerprint if
-                    config.sign_encrypted_data else None,
+                        config.sign_encrypted_data else None,
                     passphrase=enforce_passphrase(passphrase) if
-                    config.sign_encrypted_data else None,
+                        config.sign_encrypted_data else None,
                     always_trust=config.always_trust_recipient_key)
         encrypted_checksum = encrypted_checksum_buf.read()
 
@@ -223,7 +250,8 @@ def encrypt(files: List[str],
                                             for key in recipients_pub_key],
                                 purpose=purpose,
                                 checksum=HexStr256(encrypted_checksum),
-                                compression_algorithm="gzip" if compress else "")
+                                compression_algorithm='gzip' if
+                                    compression_level > 0 else '')
             metadata_bytes = json.dumps(
                 MetaData.asdict(metadata), indent=4).encode()
             metadata_signature_bytes = b""
@@ -247,13 +275,16 @@ def encrypt(files: List[str],
                 archive_content = (
                     tuple(ArchiveInMemoryFile(path, content)
                           for path, content in in_memory_files) +
-                    tuple(ArchiveFile(os.path.relpath(f.name, start=config.temp_dir), f)
+                    tuple(ArchiveFile(os.path.relpath(
+                            f.name, start=config.temp_dir), f)
                           for f in progress_file_iter(
                             files=[encrypted_file],
                             mode='rb',
                             progress=scaled_progress))
                     )
-                write_tar(archive_content, output=output_name, mode='w')
+                write_tar(content=archive_content,
+                          output=output_name,
+                          compress_level=0)
     finally:
         delete_files(encrypted_file)
 
