@@ -1,4 +1,4 @@
-from typing import List, Tuple, Callable, Dict
+from typing import List, Tuple, Callable, Dict, Optional
 import json
 
 from . import workflow
@@ -25,7 +25,7 @@ def transfer(files: List[str],
              protocol_args: dict,
              config: Config,
              dry_run: bool = False,
-             verify: bool = True,
+             verify_dtr: Optional[bool] = None,
              progress: ProgressInterface = None):
     """ Transfer file(s) to the selected recipient on the BiomedIT network.
     """
@@ -52,7 +52,9 @@ def transfer(files: List[str],
                     config.key_validation_authority_keyid,
                     config.keyserver_url))
             metadata = load_metadata(metadata)
-            if verify:
+            if verify_dtr is None:
+                verify_dtr = metadata.transfer_id is not None
+            if verify_dtr:
                 if metadata.transfer_id is None:
                     raise UserError("DTR (Data Transfer Request) ID is "
                                     "missing in file metadata.")
